nx.graphic.Topology.LayoutMixin - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.graphic.Topology.LayoutMixin Class

Module: nx.graphic.Topology

Layout mixin class

- Index
- Methods
- Properties

## Item Index

### Methods

- getLayout
- registerLayout

### Properties

- layoutConfig
- layoutMap
- layoutType

## Methods

### `getLayout`

(

- `name`

)

Get layout instance by name

#### Parameters:

- `name` String

#### Returns:

:

### `registerLayout`

(

- `name`
- `cls`

)

Register a layout

#### Parameters:

- `name` String

  layout name

- `cls` Object

  layout class instance

## Properties

### `layoutConfig`

Unknown

Current layout config

### `layoutMap`

Unknown

Layout map

### `layoutType`

Unknown

Current layout type